# Extensions to matplotlib
# lvwarren@ualr.edu
# Tue Feb 23 17:16:12 CST 2021

import math
import numpy as np
import matplotlib.pyplot as plt
from scipy.stats import norm
from cycler import cycler

van_color_list = ['#C83232', '#199619', '#0000FF', 
                  '#009696', '#BB00BB', '#FFFF00',
                  '#000000', '#FFFFFF', '#808080']

def defaults(plot, x_size=10, y_size=10):

    # # My canonical graphing style
    # plt.xkcd()
    plot.figure(figsize=(x_size,y_size)) 
#   plot.rcParams['figure.figsize'] = [10, 10] 
    plot.rcParams['figure.facecolor'] = 'FFFFFF'
    plot.rcParams.update({'font.size': 12})
    plot.rcParams['axes.facecolor'] = '#AADDAA'
    plot.rcParams['lines.linewidth'] = 3
    plot.rcParams['lines.color'] = 'red'
    plot.rcParams['axes.prop_cycle'] = cycler('color', van_color_list)
    plot.grid(True)

    
def labels(plot, x_label, y_label, title):
    plot.xlabel(x_label)
    plot.ylabel(y_label)
    plot.title(title)
    
def limits(plot, mx, px, my, py):
        plot.xlim((mx, px))
        plot.ylim((my, py))

# hidden by underscore because of singularity removal
def OoX(x):
    y = 1/x
    y[y >  math.pi] =  np.inf # remove singularity
    y[y < -math.pi] = -np.inf
    return(y)

def TaN(x):
    y = np.tan(x)
    y[y >  math.pi] =  np.inf # remove singularity
    y[y < -math.pi] = -np.inf
    return(y)
